# Generated by Django 4.0.6 on 2022-07-21 19:27

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uzcloud_billing.utils


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='BillingAccount',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('account_number', models.CharField(default=uzcloud_billing.utils.generate_account_number, max_length=255, unique=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='billing_account', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
