# Generated by Django 4.0.6 on 2022-07-22 11:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('uzcloud_billing', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='billingaccount',
            name='balance',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=10),
        ),
    ]
