# Generated by Django 4.0.6 on 2022-12-20 09:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('uzcloud_billing', '0002_billingaccount_balance'),
    ]

    operations = [
        migrations.AddField(
            model_name='billingaccount',
            name='account_type',
            field=models.IntegerField(choices=[(1, 'Individual'), (2, 'Organization')], default=1),
        ),
        migrations.AlterField(
            model_name='billingaccount',
            name='account_number',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]
